"use client";

import {MapContainer, Marker, Popup, Circle, TileLayer} from "react-leaflet";
import {divIcon} from "leaflet";
import "leaflet/dist/leaflet.css";
import ReactDOMServer from "react-dom/server";
import { SiHomebridge } from "react-icons/si";

interface Props {
  position: any;
  zoom: any;
  title: any;
}

export default function MapWidget({position, zoom, title}: Props) {
  const iconHTML = ReactDOMServer.renderToString(
    <SiHomebridge  size={40} className="text-main" />
  );

  const customIcon = divIcon({
    html: iconHTML,
    className: "custom-leaflet-icon", // Custom class for styling
    iconSize: [40, 40], // Size of the icon container
  });

  return (
    <MapContainer
      center={position}
      zoom={zoom}
      scrollWheelZoom={false}
      className="h-full z-0"
    >
      <TileLayer url="/map-tiles/{z}/{x}/{y}" />
      <Marker position={position} icon={customIcon}>
        <Popup>
          <div className="text-base text-center tracking-wide">{title}</div>
        </Popup>
      </Marker>
    </MapContainer>
  );
}
